Development
===========
.. _github: http://github.com/mig33/holmium.core/
.. _issue tracker: http://github.com/mig33/holmium.core/issues

Contributors
~~~~~~~~~~~~
.. include:: ../../CONTRIBUTORS.rst

Bugs & Feature Request
~~~~~~~~~~~~~~~~~~~~~~
* The project is hosted on `github`_. Pull requests and bug fixes can be sent via pull requests.
* Feature requests and bugs can be logged at the `issue tracker`_.


